Index: main/waeup.futminna/trunk/src/waeup/futminna/applicants/applicant.py
===================================================================
--- main/waeup.futminna/trunk/src/waeup/futminna/applicants/applicant.py	(revision 10274)
+++ main/waeup.futminna/trunk/src/waeup/futminna/applicants/applicant.py	(revision 10275)
@@ -34,5 +34,5 @@
     file_store.deleteFileByContext(applicant, attr='extraform.pdf')
     file_store.deleteFileByContext(applicant, attr='refereeform.pdf')
-    file_store.deleteFileByContext(applicant, attr='credentialform.pdf')
+    file_store.deleteFileByContext(applicant, attr='credentials.pdf')
     return
 
Index: main/waeup.futminna/trunk/src/waeup/futminna/applicants/browser_templates/applicanteditpage.pt
===================================================================
--- main/waeup.futminna/trunk/src/waeup/futminna/applicants/browser_templates/applicanteditpage.pt	(revision 10274)
+++ main/waeup.futminna/trunk/src/waeup/futminna/applicants/browser_templates/applicanteditpage.pt	(revision 10275)
@@ -90,14 +90,14 @@
       <tr tal:condition="python: view.target.startswith('pg')">
         <td class="fieldname" i18n:translate="">
-          Credential Form:
+          Credentials:
         </td>
         <td>
-          <p tal:condition="python: view.file_exists('credentialform.pdf')">
-            <a href="credentialform.pdf"
+          <p tal:condition="python: view.file_exists('credentials.pdf')">
+            <a href="credentials.pdf"
                i18n:translate="">
               Download pdf file
             </a>
           </p>
-          <input type="file" name="form.credentialform" />
+          <input type="file" name="form.credentials" />
           <br />
           <span i18n:translate="">
Index: main/waeup.futminna/trunk/src/waeup/futminna/applicants/interfaces.py
===================================================================
--- main/waeup.futminna/trunk/src/waeup/futminna/applicants/interfaces.py	(revision 10274)
+++ main/waeup.futminna/trunk/src/waeup/futminna/applicants/interfaces.py	(revision 10275)
@@ -231,4 +231,10 @@
         readonly = False,
         )
+    pp_school = schema.Choice(
+        title = _(u'Qualification Obtained'),
+        required = False,
+        readonly = False,
+        vocabulary = exam_types,
+        )
     course1 = schema.Choice(
         title = _(u'Programme desired'),
Index: main/waeup.futminna/trunk/src/waeup/futminna/applicants/browser.py
===================================================================
--- main/waeup.futminna/trunk/src/waeup/futminna/applicants/browser.py	(revision 10274)
+++ main/waeup.futminna/trunk/src/waeup/futminna/applicants/browser.py	(revision 10275)
@@ -95,7 +95,7 @@
             html += '<a href="refereeform.pdf">Referee\'s Form</a>, '
         pdf = getUtility(IExtFileStore).getFileByContext(
-            self.context, attr='credentialform.pdf')
+            self.context, attr='credentials.pdf')
         if pdf:
-            html += '<a href="credentialform.pdf">Credential Form</a>'
+            html += '<a href="credentials.pdf">Credentials</a>'
         return html
 
@@ -129,5 +129,5 @@
         self.extraform_url = self.url(self.context, 'extraform.pdf')
         self.referreeform_url = self.url(self.context, 'refereeform.pdf')
-        self.credentialform_url = self.url(self.context, 'credentialform.pdf')
+        self.credentials_url = self.url(self.context, 'credentials.pdf')
         return
 
@@ -204,11 +204,11 @@
             else:
                 self.upload_success = False
-        upload_credentialform = self.request.form.get('form.credentialform', None)
-        if upload_credentialform:
-            # We got a fresh credentialform upload
-            success = handle_file_upload(
-                upload_credentialform, self.context, self, attr='credentialform.pdf')
+        upload_credentials = self.request.form.get('form.credentials', None)
+        if upload_credentials:
+            # We got a fresh credentials upload
+            success = handle_file_upload(
+                upload_credentials, self.context, self, attr='credentials.pdf')
             if success:
-                self.context.writeLogMessage(self, 'saved: credentialform')
+                self.context.writeLogMessage(self, 'saved: credentials')
             else:
                 self.upload_success = False
@@ -250,6 +250,6 @@
             return _('No referee form pdf file uploaded.')
         if self.target is not None and self.target.startswith('pg') \
-            and not store.getFileByContext(self.context, attr=u'credentialform.pdf'):
-            return _('No credential form pdf file uploaded.')
+            and not store.getFileByContext(self.context, attr=u'credentials.pdf'):
+            return _('No credentials pdf file uploaded.')
         if not self.request.form.get('confirm_passport', False):
             return _('Passport picture confirmation box not ticked.')
@@ -277,9 +277,9 @@
             if not success:
                 self.upload_success = False
-        upload_credentialform = self.request.form.get('form.credentialform', None)
-        if upload_credentialform:
-            # We got a fresh credentialform upload
-            success = handle_file_upload(
-                upload_credentialform, self.context, self, attr='credentialform.pdf')
+        upload_credentials = self.request.form.get('form.credentials', None)
+        if upload_credentials:
+            # We got a fresh credentials upload
+            success = handle_file_upload(
+                upload_credentials, self.context, self, attr='credentials.pdf')
             if not success:
                 self.upload_success = False
@@ -313,8 +313,8 @@
         return pdf
 
-class CredentialForm(grok.View):
+class Credentials(grok.View):
     """Renders the pdf credential's form for applicants.
     """
-    grok.name('credentialform.pdf')
+    grok.name('credentials.pdf')
     grok.context(ICustomApplicant)
     grok.require('waeup.viewApplication')
@@ -322,5 +322,5 @@
     def render(self):
         pdf = getUtility(IExtFileStore).getFileByContext(
-            self.context, attr='credentialform.pdf')
+            self.context, attr='credentials.pdf')
         self.response.setHeader('Content-Type', 'application/pdf')
         return pdf
Index: main/waeup.futminna/trunk/src/waeup/futminna/applicants/tests/test_browser.py
===================================================================
--- main/waeup.futminna/trunk/src/waeup/futminna/applicants/tests/test_browser.py	(revision 10274)
+++ main/waeup.futminna/trunk/src/waeup/futminna/applicants/tests/test_browser.py	(revision 10275)
@@ -252,5 +252,5 @@
         self.assertTrue(fd is None)
 
-    def test_upload_credentialform_by_manager(self):
+    def test_upload_credentials_by_manager(self):
         self.browser.addHeader('Authorization', 'Basic mgr:mgrpw')
         self.browser.open(self.manage_path)
@@ -258,7 +258,7 @@
         pdf_content = 'A' * 1024 * 300  # A string of 300 KB size
         pseudo_pdf = StringIO(pdf_content)
         # This is a ug applicant, thus the credential form is not
         # required
-        self.assertFalse('credentialform">' in self.browser.contents)
+        self.assertFalse('credentials">' in self.browser.contents)
 
         # We have to add a pg applicants container
@@ -288,12 +288,12 @@
 
         self.browser.open(self.manage_path_pg)
-        ctrl = self.browser.getControl(name='form.credentialform')
-        file_ctrl = ctrl.mech_control
-        file_ctrl.add_file(pseudo_pdf, filename='myform.pdf')
-        self.browser.getControl("Save").click() # submit form
-        # Even though the form could not be saved ...
-        self.assertTrue('Required input is missing' in self.browser.contents)
-        # ... the file has been successfully uploaded
-        pdf_url = self.manage_path_pg.replace('manage', 'credentialform.pdf')
+        ctrl = self.browser.getControl(name='form.credentials')
+        file_ctrl = ctrl.mech_control
+        file_ctrl.add_file(pseudo_pdf, filename='myform.pdf')
+        self.browser.getControl("Save").click() # submit form
+        # Even though the form could not be saved ...
+        self.assertTrue('Required input is missing' in self.browser.contents)
+        # ... the file has been successfully uploaded
+        pdf_url = self.manage_path_pg.replace('manage', 'credentials.pdf')
         self.browser.open(pdf_url)
         self.assertEqual(
@@ -303,5 +303,5 @@
         storage = getUtility(IExtFileStore)
         file_id = IFileStoreNameChooser(applicant).chooseName(
-            attr='credentialform.pdf')
+            attr='credentials.pdf')
         # The stored file can be fetched
         fd = storage.getFile(file_id)
@@ -310,8 +310,8 @@
         # A file link is displayed on the edit view ...
         self.browser.open(self.manage_path_pg)
-        self.assertTrue('<a href="credentialform.pdf">' in self.browser.contents)
+        self.assertTrue('<a href="credentials.pdf">' in self.browser.contents)
         # ... and on the dislay view
         self.browser.open(self.view_path_pg)
-        self.assertTrue('<a href="credentialform.pdf">Credential Form</a>'
+        self.assertTrue('<a href="credentials.pdf">Credentials</a>'
             in self.browser.contents)
         # Adding file is properly logged
@@ -321,5 +321,5 @@
         self.assertTrue(
             'zope.mgr - waeup.futminna.applicants.browser.CustomApplicantManageFormPage'
-            ' - %s - saved: credentialform'
+            ' - %s - saved: credentials'
             % (applicant.applicant_id)
             in logcontent)
@@ -258,7 +258,7 @@
         pdf_content = 'A' * 1024 * 300  # A string of 300 KB size
         pseudo_pdf = StringIO(pdf_content)
-        # This is a ug applicant, thus the credential form is not
+        # This is a ug applicant, thus the credentials is not
         # required
